Groups | Search | Server Info | Keyboard shortcuts | Login | Register [http] [https] [nntp] [nntps]


Groups > alt.os.linux > #53809 > unrolled thread

gnupg sees no keys

Started byPeter Pearson <pkpearson@nowhere.invalid>
First post2019-02-14 23:46 +0000
Last post2019-02-19 16:53 +0000
Articles 20 on this page of 23 — 5 participants

Back to article view | Back to alt.os.linux


Contents

  gnupg sees no keys Peter Pearson <pkpearson@nowhere.invalid> - 2019-02-14 23:46 +0000
    Re: gnupg sees no keys Mike Easter <MikeE@ster.invalid> - 2019-02-14 16:07 -0800
      Re: gnupg sees no keys Peter Pearson <pkpearson@nowhere.invalid> - 2019-02-15 00:19 +0000
        Re: gnupg sees no keys Mike Easter <MikeE@ster.invalid> - 2019-02-14 16:58 -0800
          Re: gnupg sees no keys Peter Pearson <pkpearson@nowhere.invalid> - 2019-02-15 01:25 +0000
        Re: gnupg sees no keys "David W. Hodgins" <dwhodgins@nomail.afraid.org> - 2019-02-14 20:01 -0500
          Re: gnupg sees no keys Peter Pearson <pkpearson@nowhere.invalid> - 2019-02-15 01:36 +0000
            Re: gnupg sees no keys "David W. Hodgins" <dwhodgins@nomail.afraid.org> - 2019-02-14 22:28 -0500
              Re: gnupg sees no keys Peter Pearson <pkpearson@nowhere.invalid> - 2019-02-15 17:37 +0000
    Re: gnupg sees no keys Dan Purgert <dan@djph.net> - 2019-02-15 00:27 +0000
      Re: gnupg sees no keys Peter Pearson <pkpearson@nowhere.invalid> - 2019-02-15 00:41 +0000
        Re: gnupg sees no keys Dan Purgert <dan@djph.net> - 2019-02-15 11:22 +0000
          Re: gnupg sees no keys Peter Pearson <pkpearson@nowhere.invalid> - 2019-02-15 17:26 +0000
            Re: gnupg sees no keys "David W. Hodgins" <dwhodgins@nomail.afraid.org> - 2019-02-15 12:42 -0500
              Re: gnupg sees no keys Peter Pearson <pkpearson@nowhere.invalid> - 2019-02-15 21:08 +0000
                Re: gnupg sees no keys "David W. Hodgins" <dwhodgins@nomail.afraid.org> - 2019-02-15 16:30 -0500
                  Re: gnupg sees no keys Peter Pearson <pkpearson@nowhere.invalid> - 2019-02-16 17:14 +0000
                Re: gnupg sees no keys "David W. Hodgins" <dwhodgins@nomail.afraid.org> - 2019-02-15 16:41 -0500
                  Re: gnupg sees no keys Peter Pearson <pkpearson@nowhere.invalid> - 2019-02-16 17:08 +0000
                    Re: gnupg sees no keys "David W. Hodgins" <dwhodgins@nomail.afraid.org> - 2019-02-18 08:59 -0500
                      Re: gnupg sees no keys Peter Pearson <pkpearson@nowhere.invalid> - 2019-02-19 16:33 +0000
                        Re: gnupg sees no keys "David W. Hodgins" <dwhodgins@nomail.afraid.org> - 2019-02-19 11:43 -0500
                        Re: gnupg sees no keys William Unruh <unruh@invalid.ca> - 2019-02-19 16:53 +0000

Page 1 of 2  [1] 2  Next page →


#53809 — gnupg sees no keys

FromPeter Pearson <pkpearson@nowhere.invalid>
Date2019-02-14 23:46 +0000
Subjectgnupg sees no keys
Message-ID<gcmcuoFioc8U1@mid.individual.net>
Gnu Privacy guard, gpg, seems not to be able to find my keys:

    $ gpg --list-keys

I haven't used gpg recently, so this situation might date from
my upgrade from Debian Wheezy to Stretch.

My software seems to be up-to-date (at least as far as Stretch is
concerned), and dpkg-reconfigure seems to be helpless to get me
back to a useable state:

    $ apt-show-versions | fgrep gnupg:
    gnupg:i386/stretch 2.1.18-8~deb9u3 uptodate

    $ sudo dpkg-reconfigure gnupg
    $

As you can see, my key rings are not empty:

    $ ls -l .gnupg/
    total 2596
    drwxr-x--- 2 peter peter    4096 Aug 29  2007 Backup
    drwx------ 2 peter peter    4096 May 30  2018 crls.d
    -rw-r----- 1 peter peter    3513 Jun  5  2016 gpg.conf
    -rw------- 1 peter peter    8084 Aug 13  2006 gpg.conf.orig
    -rw-r----- 1 peter peter    3513 Mar 26  2007 gpg.conf~
    drwx------ 2 peter peter    4096 Feb  8  2018 private-keys-v1.d
    -rw------- 1 peter peter 1297276 Nov 26  2017 pubring.gpg
    -rw------- 1 peter peter 1297276 Nov 26  2017 pubring.gpg~
    -rw------- 1 peter peter    6528 May 28  2018 pubring.kbx
    -rw------- 1 peter peter    4603 May 28  2018 pubring.kbx~
    -rw------- 1 peter peter     600 Feb  6 10:40 random_seed
    -rw------- 1 peter peter    4604 Oct 29  2015 secring.gpg
    -rw------- 1 peter peter    3360 Feb  8 08:40 trustdb.gpg

Any advice would be much appreciated.

-- 
To email me, substitute nowhere->runbox, invalid->com.

[toc] | [next] | [standalone]


#53810

FromMike Easter <MikeE@ster.invalid>
Date2019-02-14 16:07 -0800
Message-ID<gcme5nFj47oU1@mid.individual.net>
In reply to#53809
Peter Pearson wrote:
> Gnu Privacy guard, gpg, seems not to be able to find my keys:
> 
>      $ gpg --list-keys

What do /you/ see when you look into the ~/.gnupg directory?

... such as .kbx and .gpg files?  Or sub-directories?

-- 
Mike Easter

[toc] | [prev] | [next] | [standalone]


#53811

FromPeter Pearson <pkpearson@nowhere.invalid>
Date2019-02-15 00:19 +0000
Message-ID<gcmernFj75oU1@mid.individual.net>
In reply to#53810
On Thu, 14 Feb 2019 16:07:17 -0800, Mike Easter <MikeE@ster.invalid> wrote:
> Peter Pearson wrote:
>> Gnu Privacy guard, gpg, seems not to be able to find my keys:
>> 
>>      $ gpg --list-keys
>
> What do /you/ see when you look into the ~/.gnupg directory?
>
> ... such as .kbx and .gpg files?  Or sub-directories?

peter@buchen:~$ ls -al ~/.gnupg
total 2620
drwx------  5 peter peter    4096 Feb  8 08:40 .
drwx------ 32 peter peter   20480 Feb 14 16:16 ..
-rw-r--r--  1 peter peter       0 Feb  8  2018 .gpg-v21-migrated
drwxr-x---  2 peter peter    4096 Aug 29  2007 Backup
drwx------  2 peter peter    4096 May 30  2018 crls.d
-rw-r-----  1 peter peter    3513 Jun  5  2016 gpg.conf
-rw-------  1 peter peter    8084 Aug 13  2006 gpg.conf.orig
-rw-r-----  1 peter peter    3513 Mar 26  2007 gpg.conf~
drwx------  2 peter peter    4096 Feb  8  2018 private-keys-v1.d
-rw-------  1 peter peter 1297276 Nov 26  2017 pubring.gpg
-rw-------  1 peter peter 1297276 Nov 26  2017 pubring.gpg~
-rw-------  1 peter peter    6528 May 28  2018 pubring.kbx
-rw-------  1 peter peter    4603 May 28  2018 pubring.kbx~
-rw-------  1 peter peter     600 Feb  6 10:40 random_seed
-rw-------  1 peter peter    4604 Oct 29  2015 secring.gpg
-rw-------  1 peter peter    3360 Feb  8 08:40 trustdb.gpg
peter@buchen:~$ 

-- 
To email me, substitute nowhere->runbox, invalid->com.

[toc] | [prev] | [next] | [standalone]


#53814

FromMike Easter <MikeE@ster.invalid>
Date2019-02-14 16:58 -0800
Message-ID<gcmh5cFjmt0U1@mid.individual.net>
In reply to#53811
Peter Pearson wrote:
> Mike Easter wrote:
>>
>> What do /you/ see when you look into the ~/.gnupg directory?
>>
> peter@buchen:~$ ls -al ~/.gnupg
> total 2620
> drwx------  5 peter peter    4096 Feb  8 08:40 

How about the ownership of the .gnupg directory itself?


-- 
Mike Easter

[toc] | [prev] | [next] | [standalone]


#53816

FromPeter Pearson <pkpearson@nowhere.invalid>
Date2019-02-15 01:25 +0000
Message-ID<gcmip4Fjd7qU2@mid.individual.net>
In reply to#53814
On Thu, 14 Feb 2019 16:58:20 -0800, Mike Easter <MikeE@ster.invalid> wrote:
> Peter Pearson wrote:
>> Mike Easter wrote:
>>>
>>> What do /you/ see when you look into the ~/.gnupg directory?
>>>
>> peter@buchen:~$ ls -al ~/.gnupg
>> total 2620
>> drwx------  5 peter peter    4096 Feb  8 08:40 
>
> How about the ownership of the .gnupg directory itself?

Me and me:

peter@buchen:~$ ls -ld .gnupg
drwx------ 5 peter peter 4096 Feb  8 08:40 .gnupg

-- 
To email me, substitute nowhere->runbox, invalid->com.

[toc] | [prev] | [next] | [standalone]


#53815

From"David W. Hodgins" <dwhodgins@nomail.afraid.org>
Date2019-02-14 20:01 -0500
Message-ID<op.zw8af3b1a3w0dxdave@hodgins.homeip.net>
In reply to#53811
On Thu, 14 Feb 2019 19:19:03 -0500, Peter Pearson <pkpearson@nowhere.invalid> wrote:

> On Thu, 14 Feb 2019 16:07:17 -0800, Mike Easter <MikeE@ster.invalid> wrote:
>> Peter Pearson wrote:
>>> Gnu Privacy guard, gpg, seems not to be able to find my keys:
>>>
>>>      $ gpg --list-keys

Run it under strace, and find out where it's looking ...
strace -f -o/tmp/trace.txt gpg --list-keys
grep open /tmp/trace.txt |grep ring

Regards, Dave Hodgins

-- 
Change dwhodgins@nomail.afraid.org to davidwhodgins@teksavvy.com for
email replies.

[toc] | [prev] | [next] | [standalone]


#53817

FromPeter Pearson <pkpearson@nowhere.invalid>
Date2019-02-15 01:36 +0000
Message-ID<gcmjc0Fjd7qU3@mid.individual.net>
In reply to#53815
On Thu, 14 Feb 2019 20:01:05 -0500, David W. Hodgins wrote:
[snip]
>>> Peter Pearson wrote:
>>>> Gnu Privacy guard, gpg, seems not to be able to find my keys:
>>>>
>>>>      $ gpg --list-keys
>
> Run it under strace, and find out where it's looking ...
> strace -f -o/tmp/trace.txt gpg --list-keys
> grep open /tmp/trace.txt |grep ring

peter@buchen:~$ strace -f -o/tmp/trace.txt gpg --list-keys
peter@buchen:~$ grep open /tmp/trace.txt | grep ring
19934 open("/home/peter/.gnupg/pubring.gpg", O_RDONLY|O_LARGEFILE) = 3
19934 open("/home/peter/.gnupg/pubring.kbx", O_RDONLY|O_LARGEFILE) = 3
19934 open("/home/peter/.gnupg/pubring.kbx", O_RDONLY|O_LARGEFILE) = 4
peter@buchen:~$ 

In fact, here's the whole interaction with the "pubrings":

19934 open("/home/peter/.gnupg/pubring.gpg", O_RDONLY|O_LARGEFILE) = 3
19934 fstat64(3, {st_mode=S_IFREG|0600, st_size=1297276, ...}) = 0
19934 read(3, "[stuff omitted]"..., 4096) = 4096
19934 close(3)                          = 0
19934 open("/home/peter/.gnupg/pubring.kbx", O_RDONLY|O_LARGEFILE) = 3
19934 fstat64(3, {st_mode=S_IFREG|0600, st_size=6528, ...}) = 0
19934 read(3, "[stuff omitted]"..., 4096) = 4096
19934 close(3)                          = 0
19934 access("/home/peter/.gnupg/pubring.kbx", F_OK) = 0
19934 access("/home/peter/.gnupg/pubring.kbx", R_OK) = 0

So, it seems to be reading something from the pubrings.

-- 
To email me, substitute nowhere->runbox, invalid->com.

[toc] | [prev] | [next] | [standalone]


#53819

From"David W. Hodgins" <dwhodgins@nomail.afraid.org>
Date2019-02-14 22:28 -0500
Message-ID<op.zw8hahj6a3w0dxdave@hodgins.homeip.net>
In reply to#53817
On Thu, 14 Feb 2019 20:36:00 -0500, Peter Pearson <pkpearson@nowhere.invalid> wrote:

> On Thu, 14 Feb 2019 20:01:05 -0500, David W. Hodgins wrote:
> [snip]
>>>> Peter Pearson wrote:
>>>>> Gnu Privacy guard, gpg, seems not to be able to find my keys:
>>>>>
>>>>>      $ gpg --list-keys
>>
>> Run it under strace, and find out where it's looking ...
>> strace -f -o/tmp/trace.txt gpg --list-keys
>> grep open /tmp/trace.txt |grep ring
>
> peter@buchen:~$ strace -f -o/tmp/trace.txt gpg --list-keys
> peter@buchen:~$ grep open /tmp/trace.txt | grep ring
> 19934 open("/home/peter/.gnupg/pubring.gpg", O_RDONLY|O_LARGEFILE) = 3
> 19934 open("/home/peter/.gnupg/pubring.kbx", O_RDONLY|O_LARGEFILE) = 3
> 19934 open("/home/peter/.gnupg/pubring.kbx", O_RDONLY|O_LARGEFILE) = 4

I wonder what the kbx files are. On my system ...
$ ll .gnupg/*ring*
-rw------- 1 dave dave 10359558 Jan 29  2013 .gnupg/backup.pubring
-rw------- 1 dave dave 22476737 Feb 14 19:53 .gnupg/pubring.gpg
-rw------- 1 dave dave 22476737 Feb 14 19:53 .gnupg/pubring.gpg~
-rw-r--r-- 1 dave dave        0 Jan 29  2013 .gnupg/pubring.kbx
-rw------- 1 dave dave    27573 Mar 15  2016 .gnupg/secring.gpg

$ grep pubring /tmp/trace.txt
24152 open("/home/dave/.gnupg/pubring.gpg", O_RDONLY) = 3
24152 access("/home/dave/.gnupg/pubring.gpg", F_OK) = 0
24152 open("/home/dave/.gnupg/pubring.gpg", O_RDONLY) = 4
24152 open("/home/dave/.gnupg/pubring.gpg", O_RDONLY) = 5
24152 write(1, "/home/dave/.gnupg/pubring.gpg\n", 30) = 30

Ah. Found it ...
$ strace -f -o/tmp/trace.txt gpg2 --list-keys
$ grep ring /tmp/trace.txt
1983  open("/home/dave/.gnupg/pubring.gpg", O_RDONLY) = 3
1983  open("/home/dave/.gnupg/pubring.kbx", O_RDONLY) = 3
1983  access("/home/dave/.gnupg/pubring.gpg", F_OK) = 0
1983  access("/home/dave/.gnupg/pubring.gpg", R_OK) = 0
1983  open("/home/dave/.gnupg/pubring.gpg", O_RDONLY) = 4
1983  open("/home/dave/.gnupg/pubring.gpg", O_RDONLY) = 5
1983  write(1, "/home/dave/.gnupg/pubring.gpg\n--"..., 8192) = 8192
1983  read(5, "t</key>\n\t\t\t\t<string>com.apple.pr"..., 8192) = 8192

So gpg2, from the package gnupg2 uses kbx files while gpg from the
gnupg package does not.

See https://superuser.com/questions/655246/are-gnupg-1-and-gnupg-2-compatible-with-each-other

Do you have the gnupg package available in your distribution?
I'm using Mageia 6 for my primary linux installation.

Regards, Dave Hodgins

-- 
Change dwhodgins@nomail.afraid.org to davidwhodgins@teksavvy.com for
email replies.

[toc] | [prev] | [next] | [standalone]


#53829

FromPeter Pearson <pkpearson@nowhere.invalid>
Date2019-02-15 17:37 +0000
Message-ID<gcobndFas3U2@mid.individual.net>
In reply to#53819
On Thu, 14 Feb 2019 22:28:55 -0500, David W. Hodgins wrote:
> On Thu, 14 Feb 2019 20:36:00 -0500, Peter Pearson wrote:
>> On Thu, 14 Feb 2019 20:01:05 -0500, David W. Hodgins wrote:
>> [snip]
>>>>> Peter Pearson wrote:
>>>>>> Gnu Privacy guard, gpg, seems not to be able to find my keys:
>>>>>>
>>>>>>      $ gpg --list-keys
>>>
>>> Run it under strace, and find out where it's looking ...
>>> strace -f -o/tmp/trace.txt gpg --list-keys
>>> grep open /tmp/trace.txt |grep ring
>>
>> peter@buchen:~$ strace -f -o/tmp/trace.txt gpg --list-keys
>> peter@buchen:~$ grep open /tmp/trace.txt | grep ring
>> 19934 open("/home/peter/.gnupg/pubring.gpg", O_RDONLY|O_LARGEFILE) = 3
>> 19934 open("/home/peter/.gnupg/pubring.kbx", O_RDONLY|O_LARGEFILE) = 3
>> 19934 open("/home/peter/.gnupg/pubring.kbx", O_RDONLY|O_LARGEFILE) = 4
>
[snip]
>
> See https://superuser.com/questions/655246/are-gnupg-1-and-gnupg-2-compatible-with-each-other

Well, that's kinda depressing: it makes it look as if GnuPG has crashed
and exploded into disorganized fragmenets.

> Do you have the gnupg package available in your distribution?
> I'm using Mageia 6 for my primary linux installation.

I'm on Debian Stretch, which has packages named gnupg and gnupg2.
As an experiment, I've "sudo apt-get purged" both (which doesn't seem
to affect the $HOME/.gnupg directory) and then "sudo apt-get installed"
them, but that doesn't change anything.  I'm toying with the idea of
purging them, deleting $HOME/.gnupg, and re-installing them.

Also, as I've mentioned elsewhere on this thread, with the -vvvv
option, gpg actually seems to admit to finding some keys, while
denying that there are any:

    peter@buchen:~$ gpg -vvvv --list-keys
    gpg: using character set 'utf-8'
    gpg: using classic trust model
    gpg: key AF01E13F42FE3A7C: accepted as trusted key
    gpg: key 0DAA9AE933B859C9: accepted as trusted key
    peter@buchen:~$ 

-- 
To email me, substitute nowhere->runbox, invalid->com.

[toc] | [prev] | [next] | [standalone]


#53812

FromDan Purgert <dan@djph.net>
Date2019-02-15 00:27 +0000
Message-ID<slrnq6c1rn.4gc.dan@xps-linux.djph.net>
In reply to#53809
-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA256

Peter Pearson wrote:
> Gnu Privacy guard, gpg, seems not to be able to find my keys:
>
>     $ gpg --list-keys
>
> I haven't used gpg recently, so this situation might date from
> my upgrade from Debian Wheezy to Stretch.
>
>
> Any advice would be much appreciated.
>

"your" keys as in personal keys? apt's keys? something else?

Have you set incorrect files in gnupg.conf, or a system variable?


-----BEGIN PGP SIGNATURE-----

iQEzBAEBCAAdFiEEBcqaUD8uEzVNxUrujhHd8xJ5ooEFAlxmB3YACgkQjhHd8xJ5
ooFNuAgAmFKTn+CTSeOYONrwPziZxIExNwHi7n/egkeEv3z3wGdx5BfSN5OFj/94
G1dq0HqgFD98nZ0L6NcECaGNIeDYhFX3t8i65f8xzoJkbTyx8Bb72N8JEoReXl7K
FLM3SjbFZYGMKN/Ey4x2g7tU/x0pBucPos9LaSvaXOlOwzinobfK0pm7XR08rwAh
u/MIBjpJ/rvYgPXOBrUyvUHgeiCJdSqUrRkAr5OF/JUGYl4Aq9xAxx8SZtHkIj38
gem3wc86BhVbYP8oZvD05RbPozK2VUcFjFcMOyEHJx3I0uVoAgJA2t0aadEqCU+D
zXiRcbxJ1RaZSgFIPDLFtXNqqzC3dw==
=wclM
-----END PGP SIGNATURE-----

-- 
|_|O|_| 
|_|_|O| Github: https://github.com/dpurgert
|O|O|O| PGP: 05CA 9A50 3F2E 1335 4DC5  4AEE 8E11 DDF3 1279 A281

[toc] | [prev] | [next] | [standalone]


#53813

FromPeter Pearson <pkpearson@nowhere.invalid>
Date2019-02-15 00:41 +0000
Message-ID<gcmg54Fjd7qU1@mid.individual.net>
In reply to#53812
On Fri, 15 Feb 2019 00:27:35 -0000 (UTC), Dan Purgert <dan@djph.net> wrote:
>
> Peter Pearson wrote:
>> Gnu Privacy guard, gpg, seems not to be able to find my keys:
>>
>>     $ gpg --list-keys
>>
>> I haven't used gpg recently, so this situation might date from
>> my upgrade from Debian Wheezy to Stretch.
>>
>>
>> Any advice would be much appreciated.
>>
>
> "your" keys as in personal keys? apt's keys? something else?

My keyrings have -- or at least used to have, and the keyring files are
still megabytes -- my public and private keys, plus the public keys of
my kids and various erstwhile co-workers.  The response that I expect
from "gpg --list-keys" is a whooshing past of a couple pages of key
descriptions.

> Have you set incorrect files in gnupg.conf, or a system variable?

I don't think there's a gnupg.conf anywhere around, and the gnupg man
page doesn't mention it.  I have a gpg.conf, which I've been using for
years, and maybe it needs to be adjusted to some Great Improved Version
of gnupg, but . . . how?

As for system variables, Yes, it could well be something like that,
but again, I'm flailing.


-- 
To email me, substitute nowhere->runbox, invalid->com.

[toc] | [prev] | [next] | [standalone]


#53826

FromDan Purgert <dan@djph.net>
Date2019-02-15 11:22 +0000
Message-ID<slrnq6d87r.4gc.dan@xps-linux.djph.net>
In reply to#53813
-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA256

Peter Pearson wrote:
> On Fri, 15 Feb 2019 00:27:35 -0000 (UTC), Dan Purgert <dan@djph.net> wrote:
>> [...]
>> Have you set incorrect files in gnupg.conf, or a system variable?
>
> I don't think there's a gnupg.conf anywhere around, and the gnupg man
> page doesn't mention it.  I have a gpg.conf, which I've been using for
> years, and maybe it needs to be adjusted to some Great Improved Version
> of gnupg, but . . . how?

Yeah, I was thinking 'gnupg/gpg.conf' and ... well didn't type it that
way.  Oops.

The config file options can be any (or all) of

  no-default-keyring (disables the use of  ~/.gnupg/pubring.gpg)
  keyring /path/to/keyring
  primary-keyring /path/to/keyring
  sec-keyring /path/to/keyring
  
Might also have "trustdb-name" set as well

If none of those are defined, then gpg(2) _SHOULD_ be pulling from
$HOME/.gnupg/pubring.gpg and $HOME/.gnupg/secring.gpg for the keys (and
$HOME/.gnupg/trustdb.gpg for the trustdb).


>
> As for system variables, Yes, it could well be something like that,
> but again, I'm flailing.

System variable would be (IIRC) $GNUPGHOME


-----BEGIN PGP SIGNATURE-----

iQEzBAEBCAAdFiEEBcqaUD8uEzVNxUrujhHd8xJ5ooEFAlxmoPsACgkQjhHd8xJ5
ooEhxQf+JW9OeA6M0EVzPZW77LE8Sg0kAa97+dwJunBgwTvbRToitkpOM9ysva79
4Qa9H8vk2T/73FsDJFB90geuG1uqs8hx5k9CBL9vZqFbPd1cQ2LGy0atDoO+01Un
vnMI1TQeR2h3vC+z6T2yOmxbgBPJi+dTIZoS6U8dOleHDVBHXLGhvyvagM8LuriG
mwoV/Nn6n2InUyKg3GXrfLUeKpMaWVrC5odmSi/Dde6Fg6xND2htNey5TsI+zOt2
O+lpGwM97MrsjDWWOc9DQfOw67ElVNP5uCj/fGKLxeQNh9L6xHoYkU6tnIRRYnN9
1U4ZrOxc6NVoMWooKULvI72KJ0dt9w==
=9Y2D
-----END PGP SIGNATURE-----

-- 
|_|O|_| 
|_|_|O| Github: https://github.com/dpurgert
|O|O|O| PGP: 05CA 9A50 3F2E 1335 4DC5  4AEE 8E11 DDF3 1279 A281

[toc] | [prev] | [next] | [standalone]


#53828

FromPeter Pearson <pkpearson@nowhere.invalid>
Date2019-02-15 17:26 +0000
Message-ID<gcob2vFas3U1@mid.individual.net>
In reply to#53826
On Fri, 15 Feb 2019 11:22:35 -0000 (UTC), Dan Purgert <dan@djph.net> wrote:
>
> The config file options can be any (or all) of
>
>   no-default-keyring (disables the use of  ~/.gnupg/pubring.gpg)
>   keyring /path/to/keyring
>   primary-keyring /path/to/keyring
>   sec-keyring /path/to/keyring
>   
> Might also have "trustdb-name" set as well
>
> If none of those are defined, then gpg(2) _SHOULD_ be pulling from
> $HOME/.gnupg/pubring.gpg and $HOME/.gnupg/secring.gpg for the keys (and
> $HOME/.gnupg/trustdb.gpg for the trustdb).

The output from strace shows that "gpg --list-keys" reads
from $HOME/.gnupg/gpg.conf, which is very simple:

    peter@buchen:~$ egrep -v '^#' .gnupg/gpg.conf | uniq
    encrypt-to 33B859C9
    no-mdc-warning
    default-key 33B859C9
    force-v3-sigs
    escape-from-lines
    lock-once


>> As for system variables, Yes, it could well be something like that,
>> but again, I'm flailing.
>
> System variable would be (IIRC) $GNUPGHOME

    peter@buchen:~$ set | fgrep PG
    peter@buchen:~$ 

Here's a bonus oddity: with the -vvvv option, gpg shows that it's
finding keys, while denying that it finds any:

    peter@buchen:~$ gpg -vvvv --list-keys
    gpg: using character set 'utf-8'
    gpg: using classic trust model
    gpg: key AF01E13F42FE3A7C: accepted as trusted key
    gpg: key 0DAA9AE933B859C9: accepted as trusted key
    peter@buchen:~$ 


-- 
To email me, substitute nowhere->runbox, invalid->com.

[toc] | [prev] | [next] | [standalone]


#53830

From"David W. Hodgins" <dwhodgins@nomail.afraid.org>
Date2019-02-15 12:42 -0500
Message-ID<op.zw9ks6e4a3w0dxdave@hodgins.homeip.net>
In reply to#53828
On Fri, 15 Feb 2019 12:26:55 -0500, Peter Pearson <pkpearson@nowhere.invalid> wrote:

> Here's a bonus oddity: with the -vvvv option, gpg shows that it's
> finding keys, while denying that it finds any:

Try ...
gpg --list-options show-unusable-uids,show-unusable-subkeys --list-keys

Regards, Dave Hodgins

-- 
Change dwhodgins@nomail.afraid.org to davidwhodgins@teksavvy.com for
email replies.

[toc] | [prev] | [next] | [standalone]


#53845

FromPeter Pearson <pkpearson@nowhere.invalid>
Date2019-02-15 21:08 +0000
Message-ID<gcoo25F43q2U1@mid.individual.net>
In reply to#53830
On Fri, 15 Feb 2019 12:42:32 -0500, David W. Hodgins wrote:
> On Fri, 15 Feb 2019 12:26:55 -0500, Peter Pearson wrote:
>
>> Here's a bonus oddity: with the -vvvv option, gpg shows that it's
>> finding keys, while denying that it finds any:
>
> Try ...
> gpg --list-options show-unusable-uids,show-unusable-subkeys --list-keys

peter@buchen:~$ gpg --list-options show-unusable-uids,show-unusable-subkeys --list-keys
peter@buchen:~$ gpg -vvvv --list-options show-unusable-uids,show-unusable-subkeys --list-keys
gpg: using character set 'utf-8'
gpg: using classic trust model
gpg: key AF01E13F42FE3A7C: accepted as trusted key
gpg: key 0DAA9AE933B859C9: accepted as trusted key
peter@buchen:~$ 

-- 
To email me, substitute nowhere->runbox, invalid->com.

[toc] | [prev] | [next] | [standalone]


#53848

From"David W. Hodgins" <dwhodgins@nomail.afraid.org>
Date2019-02-15 16:30 -0500
Message-ID<op.zw9vcrcia3w0dxdave@hodgins.homeip.net>
In reply to#53845
On Fri, 15 Feb 2019 16:08:21 -0500, Peter Pearson <pkpearson@nowhere.invalid> wrote:

> On Fri, 15 Feb 2019 12:42:32 -0500, David W. Hodgins wrote:
>> On Fri, 15 Feb 2019 12:26:55 -0500, Peter Pearson wrote:
>>
>>> Here's a bonus oddity: with the -vvvv option, gpg shows that it's
>>> finding keys, while denying that it finds any:
>>
>> Try ...
>> gpg --list-options show-unusable-uids,show-unusable-subkeys --list-keys
>
> peter@buchen:~$ gpg --list-options show-unusable-uids,show-unusable-subkeys --list-keys
> peter@buchen:~$ gpg -vvvv --list-options show-unusable-uids,show-unusable-subkeys --list-keys
> gpg: using character set 'utf-8'
> gpg: using classic trust model
> gpg: key AF01E13F42FE3A7C: accepted as trusted key
> gpg: key 0DAA9AE933B859C9: accepted as trusted key
> peter@buchen:~$

Are those the only two keys you expect to be on the ring? Are they
both expired? Is the date set properly on the computer?

Regards, Dave Hodgins

-- 
Change dwhodgins@nomail.afraid.org to davidwhodgins@teksavvy.com for
email replies.

[toc] | [prev] | [next] | [standalone]


#53882

FromPeter Pearson <pkpearson@nowhere.invalid>
Date2019-02-16 17:14 +0000
Message-ID<gcqun4FiqplU2@mid.individual.net>
In reply to#53848
On Fri, 15 Feb 2019 16:30:17 -0500, David W. Hodgins wrote:
> On Fri, 15 Feb 2019 16:08:21 -0500, Peter Pearson wrote:
>
>> On Fri, 15 Feb 2019 12:42:32 -0500, David W. Hodgins wrote:
>>> On Fri, 15 Feb 2019 12:26:55 -0500, Peter Pearson wrote:
>>>
>>>> Here's a bonus oddity: with the -vvvv option, gpg shows that it's
>>>> finding keys, while denying that it finds any:
>>>
>>> Try ...
>>> gpg --list-options show-unusable-uids,show-unusable-subkeys --list-keys
>>
>> peter@buchen:~$ gpg --list-options show-unusable-uids,show-unusable-subkeys --list-keys
>> peter@buchen:~$ gpg -vvvv --list-options show-unusable-uids,show-unusable-subkeys --list-keys
>> gpg: using character set 'utf-8'
>> gpg: using classic trust model
>> gpg: key AF01E13F42FE3A7C: accepted as trusted key
>> gpg: key 0DAA9AE933B859C9: accepted as trusted key
>> peter@buchen:~$
>
> Are those the only two keys you expect to be on the ring? Are they
> both expired? Is the date set properly on the computer?

No, I expect about a dozen keys on the ring, and while many of them
may be expired, several certainly aren't.  And my date is good.

I'm contemplating the possibility of deleting most of the
files in .gnupg, in case something went wrong with an attempted
transition from "*ring.gpg" files to "*ring.kbx" files.

-- 
To email me, substitute nowhere->runbox, invalid->com.

[toc] | [prev] | [next] | [standalone]


#53850

From"David W. Hodgins" <dwhodgins@nomail.afraid.org>
Date2019-02-15 16:41 -0500
Message-ID<op.zw9vv9l5a3w0dxdave@hodgins.homeip.net>
In reply to#53845
On Fri, 15 Feb 2019 16:08:21 -0500, Peter Pearson <pkpearson@nowhere.invalid> wrote:

> On Fri, 15 Feb 2019 12:42:32 -0500, David W. Hodgins wrote:
>> On Fri, 15 Feb 2019 12:26:55 -0500, Peter Pearson wrote:
>>
>>> Here's a bonus oddity: with the -vvvv option, gpg shows that it's
>>> finding keys, while denying that it finds any:

Another possibility. If these are very old keys, the idea plugin may
be needed. See
https://www.gnupg.org/faq/why-not-idea.html

Regards, Dave Hodgins

-- 
Change dwhodgins@nomail.afraid.org to davidwhodgins@teksavvy.com for
email replies.

[toc] | [prev] | [next] | [standalone]


#53881

FromPeter Pearson <pkpearson@nowhere.invalid>
Date2019-02-16 17:08 +0000
Message-ID<gcquc1FiqplU1@mid.individual.net>
In reply to#53850
On Fri, 15 Feb 2019 16:41:59 -0500, David W. Hodgins wrote:
> On Fri, 15 Feb 2019 16:08:21 -0500, Peter Pearson wrote:
>
>> On Fri, 15 Feb 2019 12:42:32 -0500, David W. Hodgins wrote:
>>> On Fri, 15 Feb 2019 12:26:55 -0500, Peter Pearson wrote:
>>>
>>>> Here's a bonus oddity: with the -vvvv option, gpg shows that it's
>>>> finding keys, while denying that it finds any:
>
> Another possibility. If these are very old keys, the idea plugin may
> be needed. See
> https://www.gnupg.org/faq/why-not-idea.html

Idea!  Wow, don't that take ya back.

No, not that old.  But thanks for the thought.

-- 
To email me, substitute nowhere->runbox, invalid->com.

[toc] | [prev] | [next] | [standalone]


#53905

From"David W. Hodgins" <dwhodgins@nomail.afraid.org>
Date2019-02-18 08:59 -0500
Message-ID<op.zxeug8bca3w0dxdave@hodgins.homeip.net>
In reply to#53881
On Sat, 16 Feb 2019 12:08:17 -0500, Peter Pearson <pkpearson@nowhere.invalid> wrote:

> On Fri, 15 Feb 2019 16:41:59 -0500, David W. Hodgins wrote:
>> Another possibility. If these are very old keys, the idea plugin may
>> be needed. See
>> https://www.gnupg.org/faq/why-not-idea.html

> Idea!  Wow, don't that take ya back.

 From "gpg --version" on my system ...
Cipher: IDEA, 3DES, CAST5, BLOWFISH, AES, AES192, AES256, TWOFISH,
         CAMELLIA128, CAMELLIA192, CAMELLIA256

I added the idea plugin, as it's needed for some of my older keys.

> No, not that old.  But thanks for the thought.

$ gpg --list-keys 0x6B59467D
pub   1024R/6B59467D 1993-08-15
uid                  David W. Hodgins <dwhodgins@ody.ca>
uid                  David W. Hodgins

I don't use that key anymore, but haven't revoked it. I still have
some things stored that are encrypted for that id.

My currently used key ...
$ gpg --list-keys 0x98B013E0
pub   1024D/98B013E0 1998-03-20
uid                  David W. Hodgins <davidwhodgins@gmail.com>
uid                  David W. Hodgins <DHodgin1661@Rogers.com>
sub   4096g/A3B12EFE 1998-03-20

Regards, Dave Hodgins

-- 
Change dwhodgins@nomail.afraid.org to davidwhodgins@teksavvy.com for
email replies.

[toc] | [prev] | [next] | [standalone]


Page 1 of 2  [1] 2  Next page →

Back to top | Article view | alt.os.linux


csiph-web